pyxmpp.jabberd

Package pyxmpp :: Package jabberd |
[hide private]

# Package jabberd

source code

Facilities for jabber server implementation specific features, like components.

Submodules | [hide private]
pyxmpp.jabberd.all: Convenience module containing most important objects fr pyxmpp.jabberd package. pyxmpp.jabberd.component: Jabberd external component interface (jabber:component:accept). pyxmpp.jabberd.componentstream: Component (jabber:component:accept) stream handling.

Variables | [hide private]
| __revision__ = ``'``$Id: __init__.py 714 2010-04-05 10:20:10Z jajc``...``
| __package__ = `None` hash(x)

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: __init__.py 714 2010-04-05 10:20:10Z jajcus $'